@@ -1,8 +1,8 @@
 package Module::Build::Config;
 
 use strict;
-use vars qw($VERSION);
-$VERSION = '0.40_11';
+use warnings;
+our $VERSION = '0.42_13';
 $VERSION = eval $VERSION;
 use Config;
 
