@@ -1,7 +1,7 @@
 package Module::Build::Cookbook;
 use strict;
-use vars qw($VERSION);
-$VERSION = '0.40_11';
+use warnings;
+our $VERSION = '0.42_13';
 
 
 =head1 NAME
