@@ -1,13 +1,12 @@
 package Module::Build::Platform::Unix;
 
 use strict;
-use vars qw($VERSION);
-$VERSION = '0.40_11';
+use warnings;
+our $VERSION = '0.42_13';
 $VERSION = eval $VERSION;
 use Module::Build::Base;
 
-use vars qw(@ISA);
-@ISA = qw(Module::Build::Base);
+our @ISA = qw(Module::Build::Base);
 
 sub is_executable {
   # We consider the owner bit to be authoritative on a file, because
@@ -43,8 +42,8 @@ sub _detildefy {
   my ($self, $value) = @_;
   $value =~ s[^~([^/]+)?(?=/|$)]   # tilde with optional username
     [$1 ?
-     ((getpwnam $1)[7] || "~$1") :
-     ($ENV{HOME} || (getpwuid $>)[7])
+     (eval{(getpwnam $1)[7]} || "~$1") :
+     ($ENV{HOME} || eval{(getpwuid $>)[7]} || glob("~"))
     ]ex;
   return $value;
 }
